checkCache method

  1. @override
Future<bool> checkCache(
  1. String key
)
override

check time storage if cached data exists and is valid key - the key used to store the data data - string version of the data to be stored

Implementation

@override
Future<bool> checkCache(String key) async {
  final time = cacheTimeBox.getKey<Object>(key)?.asInt;
  if (time == null) return false;
  return !time.isPast;
}