Pagination class abstract

Available extensions

Constructors

Pagination({int total = 0, int limit = 0, int pages = 0, int page = 1, String? order, String? query})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasNext → bool

Available on Pagination, provided by the PaginationExt extension

no setter
hasPrevious → bool

Available on Pagination, provided by the PaginationExt extension

no setter
limit → int
final
order → String?
final
page → int
final
pages → int
final
query → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited