cacheHit constant
int
const cacheHit
Status code used when a response is served from the local cache.
Implementation
static const int cacheHit = 210;
Status code used when a response is served from the local cache.
static const int cacheHit = 210;