cancelled constant
int
const cancelled
Status code used when the call was cancelled via its CancellationToken.
Implementation
static const int cancelled = -1;
Status code used when the call was cancelled via its CancellationToken.
static const int cancelled = -1;