isCancelled property

bool get isCancelled

True when this response is the result of a cancellation rather than a failure worth reporting to the user.

Implementation

bool get isCancelled => statusCode == ApiResponse.cancelled;