FileFormField class

class for handling file upload

Constructors

FileFormField({List<int>? bytes, String? stringFile, String? path, String? key})

Properties

bytes → List<int>?
file bytes
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
file key to be used in the form data
final
path → String?
file path
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringFile → String?
file key to be used in the form data
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited