remote/interceptors/index library
Classes
- ApiInterceptor
- Api interceptor interface.
- HeaderInterceptor
- an interceptor to add headers to a request before initiating it
-
JsonInterceptor<
ErrorType> - Decodes response bodies into typed models using a registry of factories.
- LoggingInterceptor
-
Logs each request and its outcome through
ApiConfig().logger.