ApiConfig class

Process-wide configuration for the package.

Constructors

ApiConfig()
factory

Properties

defaultErrorMessage String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logger ↔ void Function(String message)?
Sink for the package's diagnostic output.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

log(String message) → void
Emits message to logger when one is configured, and does nothing otherwise.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cancelledCode → const int
Error code reported when a call is cancelled via its CancellationToken.
interceptorFailureCode → const int
Error code reported when an interceptor throws while resolving a response.