cancelledCode constant
int
const cancelledCode
Error code reported when a call is cancelled via its CancellationToken.
Implementation
static const int cancelledCode = 7014;
Error code reported when a call is cancelled via its CancellationToken.
static const int cancelledCode = 7014;