CacheManager class
Cache manager class that handles all the cache operations
Constructors
- CacheManager({String directoryName = 'data_repository_cache'})
Properties
- directoryName → String
-
Subdirectory of the temporary directory that entries are written to.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> - removes every entry this manager owns
-
fileNameFor(
String key) → String - Maps a cache key to a filename.
-
getCachedData(
String key) → Future< String?> - returns data stored in the cache for the given key
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → Future< void> -
removes the entry for
key, if any -
saveToCache(
String key, String data) → Future< bool> - stores data in the cache for the given key
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited