ApiErrorStatus extension
- on
Properties
- hasHttpStatusCode → bool
-
Available on ApiError, provided by the ApiErrorStatus extension
True when ApiError.code falls in the range of a real HTTP status code, meaning it can meaningfully be surfaced asApiResponse.statusCode.no setter